@@ -16,6 +16,7 @@ package cli
 
 import (
 	"context"
+	"fmt"
 	"io"
 	"os"
 	"os/signal"
@@ -29,6 +30,7 @@ import (
 	"github.com/dolthub/dolt/go/libraries/events"
 	"github.com/dolthub/dolt/go/libraries/utils/argparser"
 	"github.com/dolthub/dolt/go/store/nbs"
+	"github.com/dolthub/dolt/go/store/types"
 )
 
 func isHelp(str string) bool {
@@ -111,6 +113,12 @@ type HiddenCommand interface {
 	Hidden() bool
 }
 
+type FormatGatedCommand interface {
+	Command
+
+	GatedForNBF(nbf *types.NomsBinFormat) bool
+}
+
 // SubCommandHandler is a command implementation which holds subcommands which can be called
 type SubCommandHandler struct {
 	name        string
@@ -219,6 +227,14 @@ func (hc SubCommandHandler) handleCommand(ctx context.Context, commandStr string
 		defer stop()
 	}
 
+	fgc, ok := cmd.(FormatGatedCommand)
+	if ok && dEnv.DoltDB != nil && fgc.GatedForNBF(dEnv.DoltDB.Format()) {
+		vs := dEnv.DoltDB.Format().VersionString()
+		err := fmt.Sprintf("Dolt command '%s' is not supported in format %s", cmd.Name(), vs)
+		PrintErrln(color.YellowString(err))
+		return 1
+	}
+
 	ret := cmd.Exec(ctx, commandStr, args, dEnv)
 
 	if evt != nil {
