@@ -242,7 +242,7 @@ func logCommits(ctx context.Context, dEnv *env.DoltEnv, cs *doltdb.CommitSpec, o
 
 	var commitsInfo []logNode
 	for _, comm := range commits {
-		meta, mErr := comm.GetCommitMeta()
+		meta, mErr := comm.GetCommitMeta(ctx)
 		if mErr != nil {
 			cli.PrintErrln("error: failed to get commit metadata")
 			return 1
@@ -274,7 +274,7 @@ func logCommits(ctx context.Context, dEnv *env.DoltEnv, cs *doltdb.CommitSpec, o
 }
 
 func tableExists(ctx context.Context, commit *doltdb.Commit, tableName string) (bool, error) {
-	rv, err := commit.GetRootValue()
+	rv, err := commit.GetRootValue(ctx)
 	if err != nil {
 		return false, err
 	}
@@ -337,12 +337,12 @@ func logTableCommits(ctx context.Context, dEnv *env.DoltEnv, opts logOpts, cs *d
 			continue
 		}
 
-		parentRV, err := c.GetRootValue()
+		parentRV, err := c.GetRootValue(ctx)
 		if err != nil {
 			return err
 		}
 
-		childRV, err := prevCommit.GetRootValue()
+		childRV, err := prevCommit.GetRootValue(ctx)
 		if err != nil {
 			return err
 		}
@@ -353,7 +353,7 @@ func logTableCommits(ctx context.Context, dEnv *env.DoltEnv, opts logOpts, cs *d
 		}
 
 		if ok {
-			meta, err := prevCommit.GetCommitMeta()
+			meta, err := prevCommit.GetCommitMeta(ctx)
 			if err != nil {
 				return err
 			}
