@@ -250,7 +250,7 @@ func (r nomsRvStorage) nomsValue() types.Value {
 func newRootValue(vrw types.ValueReadWriter, v types.Value) (*RootValue, error) {
 	var storage rvStorage
 
-	if vrw.Format() == types.Format_DOLT_DEV {
+	if vrw.Format().UsesFlatbuffers() {
 		srv := serial.GetRootAsRootValue([]byte(v.(types.SerialMessage)), 0)
 		storage = fbRvStorage{srv}
 	} else {
@@ -278,7 +278,7 @@ func newRootValue(vrw types.ValueReadWriter, v types.Value) (*RootValue, error)
 }
 
 func isRootValue(nbf *types.NomsBinFormat, val types.Value) bool {
-	if nbf == types.Format_DOLT_DEV {
+	if nbf.UsesFlatbuffers() {
 		if sm, ok := val.(types.SerialMessage); ok {
 			return string(serial.GetFileID([]byte(sm))) == serial.RootValueFileID
 		}
@@ -291,7 +291,7 @@ func isRootValue(nbf *types.NomsBinFormat, val types.Value) bool {
 }
 
 func EmptyRootValue(ctx context.Context, vrw types.ValueReadWriter) (*RootValue, error) {
-	if vrw.Format() == types.Format_DOLT_DEV {
+	if vrw.Format().UsesFlatbuffers() {
 		builder := flatbuffers.NewBuilder(80)
 		var empty hash.Hash
 		serial.RefMapStart(builder)
@@ -470,7 +470,10 @@ func (root *RootValue) GenerateTagsForNewColumns(
 	if headRoot != nil {
 		for _, col := range existingCols {
 			for i := range newColNames {
-				if strings.ToLower(newColNames[i]) == strings.ToLower(col.Name) {
+				// Only re-use tags if the noms kind didn't change
+				// TODO: revisit this when new storage format is further along
+				if strings.ToLower(newColNames[i]) == strings.ToLower(col.Name) &&
+					newColKinds[i] == col.TypeInfo.NomsKind() {
 					newTags[i] = col.Tag
 					break
 				}
@@ -1052,7 +1055,7 @@ func (root *RootValue) RemoveTables(ctx context.Context, skipFKHandling bool, al
 			return nil, err
 		}
 		if a.IsEmpty() {
-			return nil, ErrTableNotFound
+			return nil, fmt.Errorf("%w: '%s'", ErrTableNotFound, name)
 		}
 		edits[i].name = name
 	}
@@ -1307,6 +1310,10 @@ func validateTagUniqueness(ctx context.Context, root *RootValue, tableName strin
 	return nil
 }
 
+type debugStringer interface {
+	DebugString(ctx context.Context) string
+}
+
 // DebugString returns a human readable string with the contents of this root. If |transitive| is true, row data from
 // all tables is also included. This method is very expensive for large root values, so |transitive| should only be used
 // when debugging tests.
@@ -1319,8 +1326,21 @@ func (root *RootValue) DebugString(ctx context.Context, transitive bool) string
 		root.IterTables(ctx, func(name string, table *Table, sch schema.Schema) (stop bool, err error) {
 			buf.WriteString("\nTable ")
 			buf.WriteString(name)
-			buf.WriteString(": \n")
-			buf.WriteString(table.table.DebugString(ctx))
+			buf.WriteString("\n")
+
+			buf.WriteString("Struct:\n")
+			buf.WriteString(table.DebugString(ctx))
+
+			buf.WriteString("\ndata:\n")
+			data, err := table.GetNomsRowData(ctx)
+			if err != nil {
+				panic(err)
+			}
+
+			err = types.WriteEncodedValue(ctx, &buf, data)
+			if err != nil {
+				panic(err)
+			}
 			return false, nil
 		})
 	}
