@@ -44,15 +44,16 @@ const (
 	tableWriterStatUpdateRate = 64 * 1024
 )
 
-// type SqlEngineTableWriter is a utility for importing a set of rows through the sql engine.
+// SqlEngineTableWriter is a utility for importing a set of rows through the sql engine.
 type SqlEngineTableWriter struct {
 	se     *engine.SqlEngine
 	sqlCtx *sql.Context
 
-	tableName string
-	database  string
-	contOnErr bool
-	force     bool
+	tableName  string
+	database   string
+	contOnErr  bool
+	force      bool
+	disableFks bool
 
 	statsCB noms.StatsCB
 	stats   types.AppliedEditStats
@@ -76,6 +77,7 @@ func NewSqlEngineTableWriter(ctx context.Context, dEnv *env.DoltEnv, createTable
 		return true, nil
 	})
 
+	// Simplest path would have our import path be a layer over load data
 	se, err := engine.NewSqlEngine(ctx, mrEnv, engine.FormatCsv, dbName, false, nil, false)
 	if err != nil {
 		return nil, err
@@ -105,10 +107,11 @@ func NewSqlEngineTableWriter(ctx context.Context, dEnv *env.DoltEnv, createTable
 	}
 
 	return &SqlEngineTableWriter{
-		se:        se,
-		sqlCtx:    sqlCtx,
-		contOnErr: options.ContinueOnErr,
-		force:     options.Force,
+		se:         se,
+		sqlCtx:     sqlCtx,
+		contOnErr:  options.ContinueOnErr,
+		force:      options.Force,
+		disableFks: options.DisableFks,
 
 		database:  dbName,
 		tableName: options.TableToWriteTo,
@@ -144,10 +147,11 @@ func NewSqlEngineTableWriterWithEngine(ctx *sql.Context, eng *sqle.Engine, db ds
 	}
 
 	return &SqlEngineTableWriter{
-		se:        engine.NewRebasedSqlEngine(eng, map[string]dsqle.SqlDatabase{db.Name(): db}),
-		sqlCtx:    ctx,
-		contOnErr: options.ContinueOnErr,
-		force:     options.Force,
+		se:         engine.NewRebasedSqlEngine(eng, map[string]dsqle.SqlDatabase{db.Name(): db}),
+		sqlCtx:     ctx,
+		contOnErr:  options.ContinueOnErr,
+		force:      options.Force,
+		disableFks: options.DisableFks,
 
 		database:  db.Name(),
 		tableName: options.TableToWriteTo,
@@ -170,6 +174,13 @@ func (s *SqlEngineTableWriter) WriteRows(ctx context.Context, inputChannel chan
 		return err
 	}
 
+	if s.disableFks {
+		_, _, err = s.se.Query(s.sqlCtx, fmt.Sprintf("SET FOREIGN_KEY_CHECKS = 0"))
+		if err != nil {
+			return err
+		}
+	}
+
 	err = s.createOrEmptyTableIfNeeded()
 	if err != nil {
 		return err
