@@ -231,3 +231,13 @@ func IsUsingSpatialColAsKey(sch Schema) bool {
 	}
 	return false
 }
+
+// Adapt adapts the |from| schema to the |to| schema, applying all the necessary metadata (foreign keys, constraints,
+// etc) present in |from| to |to| and returning the result.
+func Adapt(from, to Schema) (Schema, error) {
+	fromSch, toSch := from.(*schemaImpl), to.(*schemaImpl)
+	// TODO: this doesn't work in many cases, the indexes and checks themselves need to be adapted
+	toSch.indexCollection = fromSch.indexCollection
+	toSch.checkCollection = fromSch.checkCollection
+	return toSch, nil
+}
