@@ -26,38 +26,43 @@ const MergeFuncName = "merge"
 
 var ErrUncommittedChanges = goerrors.NewKind("cannot merge with uncommitted changes")
 
+// Deprecated: please use the version in the dprocedures package
 type MergeFunc struct {
 	children []sql.Expression
 }
 
 // NewMergeFunc creates a new MergeFunc expression.
+// Deprecated: please use the version in the dprocedures package
 func NewMergeFunc(args ...sql.Expression) (sql.Expression, error) {
 	return &MergeFunc{children: args}, nil
 }
 
 // Eval implements the Expression interface.
-// todo(andy): merge with DOLT_MERGE()
-func (cf *MergeFunc) Eval(ctx *sql.Context, row sql.Row) (interface{}, error) {
-	return doDoltMerge(ctx, row, cf.Children())
+func (mf *MergeFunc) Eval(ctx *sql.Context, row sql.Row) (interface{}, error) {
+	args, err := getDoltArgs(ctx, row, mf.Children())
+	if err != nil {
+		return noConflicts, err
+	}
+	return DoDoltMerge(ctx, args)
 }
 
 // String implements the Stringer interface.
-func (cf *MergeFunc) String() string {
-	childrenStrings := make([]string, len(cf.children))
+func (mf *MergeFunc) String() string {
+	childrenStrings := make([]string, len(mf.children))
 
-	for i, child := range cf.children {
+	for i, child := range mf.children {
 		childrenStrings[i] = child.String()
 	}
 	return fmt.Sprintf("Merge(%s)", strings.Join(childrenStrings, ","))
 }
 
 // IsNullable implements the Expression interface.
-func (cf *MergeFunc) IsNullable() bool {
+func (mf *MergeFunc) IsNullable() bool {
 	return false
 }
 
-func (cf *MergeFunc) Resolved() bool {
-	for _, child := range cf.Children() {
+func (mf *MergeFunc) Resolved() bool {
+	for _, child := range mf.Children() {
 		if !child.Resolved() {
 			return false
 		}
@@ -65,16 +70,16 @@ func (cf *MergeFunc) Resolved() bool {
 	return true
 }
 
-func (cf *MergeFunc) Children() []sql.Expression {
-	return cf.children
+func (mf *MergeFunc) Children() []sql.Expression {
+	return mf.children
 }
 
 // WithChildren implements the Expression interface.
-func (cf *MergeFunc) WithChildren(children ...sql.Expression) (sql.Expression, error) {
+func (mf *MergeFunc) WithChildren(children ...sql.Expression) (sql.Expression, error) {
 	return NewMergeFunc(children...)
 }
 
 // Type implements the Expression interface.
-func (cf *MergeFunc) Type() sql.Type {
+func (mf *MergeFunc) Type() sql.Type {
 	return sql.Text
 }
