@@ -171,7 +171,7 @@ func (sess *Session) Flush(ctx *sql.Context, dbName string) error {
 	return sess.SetRoot(ctx, dbName, ws.WorkingRoot())
 }
 
-// CommitTransaction commits the in-progress transaction for the database named
+// StartTransaction refreshes the state of this session and starts a new transaction.
 func (sess *Session) StartTransaction(ctx *sql.Context, dbName string, tCharacteristic sql.TransactionCharacteristic) (sql.Transaction, error) {
 	if TransactionsDisabled(ctx) {
 		return DisabledTransaction{}, nil
@@ -853,7 +853,7 @@ func (sess *Session) AddDB(ctx *sql.Context, dbState InitialDbState) error {
 	//  the writer with one that errors out
 	sessionState.dbData = dbState.DbData
 	sessionState.tmpFileDir = dbState.DbData.Rsw.TempTableFilesDir()
-	adapter := NewSessionStateAdapter(sess, db.Name(), dbState.Remotes, dbState.Branches)
+	adapter := NewSessionStateAdapter(sess, db.Name(), dbState.Remotes, dbState.Branches, dbState.Backups)
 	sessionState.dbData.Rsr = adapter
 	sessionState.dbData.Rsw = adapter
 	sessionState.readOnly, sessionState.readReplica = dbState.ReadOnly, dbState.ReadReplica
