@@ -79,9 +79,7 @@ func newDoltHarness(t *testing.T) *DoltHarness {
 
 	if types.IsFormat_DOLT_1(dEnv.DoltDB.Format()) {
 		dh = dh.WithSkippedQueries([]string{
-			"show",        // todo(andy): "show_create_table_t2"
-			"foreign key", //TODO: Daylon
-			"no_primary",
+			"SHOW CREATE TABLE child", // todo(andy): "TestForeignKeys - ALTER TABLE RENAME COLUMN"
 		})
 	}
 
