@@ -21,7 +21,6 @@ import (
 	"github.com/dolthub/go-mysql-server/enginetest"
 	"github.com/dolthub/go-mysql-server/sql"
 
-	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dfunctions"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
@@ -51,7 +50,7 @@ var ShowCreateTableAsOfScriptTest = enginetest.ScriptTest{
 					"  `pk` int NOT NULL,\n" +
 					"  `c1` int,\n" +
 					"  PRIMARY KEY (`pk`)\n" +
-					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4",
+					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin",
 				},
 			},
 		},
@@ -63,7 +62,7 @@ var ShowCreateTableAsOfScriptTest = enginetest.ScriptTest{
 					"  `c1` int,\n" +
 					"  `c2` text,\n" +
 					"  PRIMARY KEY (`pk`)\n" +
-					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4",
+					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin",
 				},
 			},
 		},
@@ -75,7 +74,7 @@ var ShowCreateTableAsOfScriptTest = enginetest.ScriptTest{
 					"  `c2` text,\n" +
 					"  PRIMARY KEY (`pk`),\n" +
 					"  UNIQUE KEY `c2` (`c2`)\n" +
-					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4",
+					") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin",
 				},
 			},
 		},
@@ -174,7 +173,7 @@ var DoltScripts = []enginetest.ScriptTest{
 						"  PRIMARY KEY (`a`),\n" +
 						"  KEY `t1b` (`b`),\n" +
 						"  CONSTRAINT `ck1` CHECK (`b` LIKE \"%abc%\")\n" +
-						") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4"},
+						") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin"},
 				},
 			},
 			{
@@ -186,7 +185,7 @@ var DoltScripts = []enginetest.ScriptTest{
 						"  PRIMARY KEY (`c`),\n" +
 						"  UNIQUE KEY `d_0` (`d`),\n" +
 						"  CONSTRAINT `fk1` FOREIGN KEY (`d`) REFERENCES `t1` (`b`)\n" +
-						") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4"},
+						") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin"},
 				},
 			},
 		},
@@ -216,6 +215,24 @@ var DoltScripts = []enginetest.ScriptTest{
 			},
 		},
 	},
+	{
+		Name: "SHOW CREATE PROCEDURE works with Dolt external procedures",
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query: "SHOW CREATE PROCEDURE dolt_checkout;",
+				Expected: []sql.Row{
+					{
+						"dolt_checkout",
+						"",
+						"CREATE PROCEDURE dolt_checkout() SELECT 'External stored procedure defined by mydb';",
+						"utf8mb4",
+						"utf8mb4_0900_bin",
+						"utf8mb4_0900_bin",
+					},
+				},
+			},
+		},
+	},
 }
 
 func makeLargeInsert(sz int) string {
@@ -889,7 +906,7 @@ var DoltMerge = []enginetest.ScriptTest{
 			},
 			{
 				Query:          "SELECT DOLT_MERGE('feature-branch')",
-				ExpectedErrStr: doltdb.ErrUnresolvedConflicts.Error(),
+				ExpectedErrStr: dsess.ErrUnresolvedConflictsCommit.Error(),
 			},
 			{
 				Query:    "SELECT count(*) from dolt_conflicts_test", // transaction has been rolled back, 0 results
@@ -970,6 +987,61 @@ var DoltMerge = []enginetest.ScriptTest{
 	},
 }
 
+var DoltReset = []enginetest.ScriptTest{
+	{
+		Name: "CALL DOLT_RESET('--hard') should reset the merge state after uncommitted merge",
+		SetUpScript: []string{
+			"CREATE TABLE test1 (pk int NOT NULL, c1 int, c2 int, PRIMARY KEY (pk));",
+			"INSERT INTO test1 values (0,1,1);",
+			"CALL DOLT_COMMIT('-am', 'added table')",
+
+			"CALL DOLT_CHECKOUT('-b', 'merge_branch');",
+			"UPDATE test1 set c1 = 2;",
+			"CALL DOLT_COMMIT('-am', 'update pk 0 = 2,1 to test1');",
+
+			"CALL DOLT_CHECKOUT('main');",
+			"UPDATE test1 set c2 = 2;",
+			"CALL DOLT_COMMIT('-am', 'update pk 0 = 1,2 to test1');",
+
+			"CALL DOLT_MERGE('merge_branch');",
+
+			"CALL DOLT_RESET('--hard');",
+		},
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query:          "CALL DOLT_MERGE('--abort')",
+				ExpectedErrStr: "fatal: There is no merge to abort",
+			},
+		},
+	},
+	{
+		Name: "CALL DOLT_RESET('--hard') should reset the merge state after conflicting merge",
+		SetUpScript: []string{
+			"SET dolt_allow_commit_conflicts = on",
+			"CREATE TABLE test1 (pk int NOT NULL, c1 int, c2 int, PRIMARY KEY (pk));",
+			"INSERT INTO test1 values (0,1,1);",
+			"CALL DOLT_COMMIT('-am', 'added table')",
+
+			"CALL DOLT_CHECKOUT('-b', 'merge_branch');",
+			"UPDATE test1 set c1 = 2, c2 = 2;",
+			"CALL DOLT_COMMIT('-am', 'update pk 0 = 2,2 to test1');",
+
+			"CALL DOLT_CHECKOUT('main');",
+			"UPDATE test1 set c1 = 3, c2 = 3;",
+			"CALL DOLT_COMMIT('-am', 'update pk 0 = 3,3 to test1');",
+
+			"CALL DOLT_MERGE('merge_branch');",
+			"CALL DOLT_RESET('--hard');",
+		},
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query:          "CALL DOLT_MERGE('--abort')",
+				ExpectedErrStr: "fatal: There is no merge to abort",
+			},
+		},
+	},
+}
+
 var DiffSystemTableScriptTests = []enginetest.ScriptTest{
 	{
 		Name: "base case: added rows",
@@ -1359,6 +1431,21 @@ var DiffSystemTableScriptTests = []enginetest.ScriptTest{
 			},
 		},
 	},
+	{
+		Name: "table with commit column should maintain its data in diff",
+		SetUpScript: []string{
+			"CREATE TABLE t (pk int PRIMARY KEY, commit text);",
+			"CALL dolt_commit('-am', 'creating table t');",
+			"INSERT INTO t VALUES (1, 'hi');",
+			"CALL dolt_commit('-am', 'insert data');",
+		},
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query:    "SELECT to_pk, to_commit, from_pk, from_commit, diff_type from dolt_diff_t;",
+				Expected: []sql.Row{{1, "hi", nil, nil, "added"}},
+			},
+		},
+	},
 }
 
 var DiffTableFunctionScriptTests = []enginetest.ScriptTest{
@@ -1719,6 +1806,21 @@ var DiffTableFunctionScriptTests = []enginetest.ScriptTest{
 			},
 		},
 	},
+	{
+		Name: "table with commit column should maintain its data in diff",
+		SetUpScript: []string{
+			"CREATE TABLE t (pk int PRIMARY KEY, commit text);",
+			"set @Commit1 = dolt_commit('-am', 'creating table t');",
+			"INSERT INTO t VALUES (1, 'hi');",
+			"set @Commit2 = dolt_commit('-am', 'insert data');",
+		},
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query:    "SELECT to_pk, to_commit, from_pk, from_commit, diff_type from dolt_diff('t', @Commit1, @Commit2);",
+				Expected: []sql.Row{{1, "hi", nil, nil, "added"}},
+			},
+		},
+	},
 }
 
 var UnscopedDiffSystemTableScriptTests = []enginetest.ScriptTest{
