@@ -20,11 +20,39 @@ import (
 	"github.com/dolthub/go-mysql-server/sql/plan"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
-
-	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 )
 
 var DoltTransactionTests = []enginetest.TransactionTest{
+	{
+		// Repro for https://github.com/dolthub/dolt/issues/3402
+		Name: "DDL changes from transactions are available before analyzing statements in other sessions (autocommit on)",
+		Assertions: []enginetest.ScriptTestAssertion{
+			{
+				Query:    "/* client a */ select @@autocommit;",
+				Expected: []sql.Row{{1}},
+			},
+			{
+				Query:    "/* client b */ select @@autocommit;",
+				Expected: []sql.Row{{1}},
+			},
+			{
+				Query:       "/* client a */ select * from t;",
+				ExpectedErr: sql.ErrTableNotFound,
+			},
+			{
+				Query:       "/* client b */ select * from t;",
+				ExpectedErr: sql.ErrTableNotFound,
+			},
+			{
+				Query:    "/* client a */ create table t(pk int primary key);",
+				Expected: []sql.Row{{sql.OkResult{}}},
+			},
+			{
+				Query:    "/* client b */ select count(*) from t;",
+				Expected: []sql.Row{{0}},
+			},
+		},
+	},
 	{
 		Name: "duplicate inserts, autocommit on",
 		SetUpScript: []string{
@@ -1111,7 +1139,7 @@ var DoltConflictHandlingTests = []enginetest.TransactionTest{
 			},
 			{
 				Query:          "/* client b */ commit",
-				ExpectedErrStr: doltdb.ErrUnresolvedConflicts.Error(),
+				ExpectedErrStr: dsess.ErrUnresolvedConflictsCommit.Error(),
 			},
 			{ // our transaction got rolled back, so we lose the above insert
 				Query:    "/* client b */ select * from test order by 1",
@@ -1195,7 +1223,7 @@ var DoltSqlFuncTransactionTests = []enginetest.TransactionTest{
 			},
 			{
 				Query:          "/* client a */ SELECT DOLT_MERGE('feature-branch')",
-				ExpectedErrStr: doltdb.ErrUnresolvedConflicts.Error(),
+				ExpectedErrStr: dsess.ErrUnresolvedConflictsCommit.Error(),
 			},
 			{ // client rolled back on merge with conflicts
 				Query:    "/* client a */ SELECT count(*) from dolt_conflicts_test",
