@@ -23,6 +23,7 @@ import (
 
 	"github.com/dolthub/go-mysql-server/sql"
 
+	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb/durable"
 	"github.com/dolthub/dolt/go/libraries/doltcore/row"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
@@ -35,44 +36,49 @@ func PartitionIndexedTableRows(ctx *sql.Context, idx sql.Index, part sql.Partiti
 	rp := part.(rangePartition)
 	doltIdx := idx.(DoltIndex)
 
-	if types.IsFormat_DOLT_1(rp.rows.Format()) {
-		return RowIterForProllyRange(ctx, doltIdx, rp.prollyRange, pkSch, columns)
+	if types.IsFormat_DOLT_1(rp.primary.Format()) {
+		return RowIterForProllyRange(ctx, doltIdx, rp.prollyRange, pkSch, columns, rp.primary, rp.secondary)
 	}
 
 	ranges := []*noms.ReadRange{rp.nomsRange}
-	return RowIterForNomsRanges(ctx, doltIdx, ranges, rp.rows, columns)
+	return RowIterForNomsRanges(ctx, doltIdx, ranges, columns, rp.primary, rp.secondary)
 }
 
-func RowIterForIndexLookup(ctx *sql.Context, ilu sql.IndexLookup, pkSch sql.PrimaryKeySchema, columns []string) (sql.RowIter, error) {
+func RowIterForIndexLookup(ctx *sql.Context, t *doltdb.Table, ilu sql.IndexLookup, pkSch sql.PrimaryKeySchema, columns []string) (sql.RowIter, error) {
 	lookup := ilu.(*doltIndexLookup)
 	idx := lookup.idx
 
+	primary, secondary, err := idx.GetDurableIndexes(ctx, t)
+	if err != nil {
+		return nil, err
+	}
+
 	if types.IsFormat_DOLT_1(idx.Format()) {
 		// todo(andy)
-		return RowIterForProllyRange(ctx, idx, lookup.prollyRanges[0], pkSch, columns)
+		return RowIterForProllyRange(ctx, idx, lookup.prollyRanges[0], pkSch, columns, primary, secondary)
 	} else {
-		return RowIterForNomsRanges(ctx, idx, lookup.nomsRanges, lookup.IndexRowData(), columns)
+		return RowIterForNomsRanges(ctx, idx, lookup.nomsRanges, columns, primary, secondary)
 	}
 }
 
-func RowIterForProllyRange(ctx *sql.Context, idx DoltIndex, ranges prolly.Range, pkSch sql.PrimaryKeySchema, columns []string) (sql.RowIter2, error) {
+func RowIterForProllyRange(ctx *sql.Context, idx DoltIndex, ranges prolly.Range, pkSch sql.PrimaryKeySchema, columns []string, primary, secondary durable.Index) (sql.RowIter2, error) {
 	covers := indexCoversCols(idx, columns)
 	if covers {
-		return newProllyCoveringIndexIter(ctx, idx, ranges, pkSch)
+		return newProllyCoveringIndexIter(ctx, idx, ranges, pkSch, secondary)
 	} else {
-		return newProllyIndexIter(ctx, idx, ranges)
+		return newProllyIndexIter(ctx, idx, ranges, primary, secondary)
 	}
 }
 
-func RowIterForNomsRanges(ctx *sql.Context, idx DoltIndex, ranges []*noms.ReadRange, rowData durable.Index, columns []string) (sql.RowIter, error) {
-	m := durable.NomsMapFromIndex(rowData)
+func RowIterForNomsRanges(ctx *sql.Context, idx DoltIndex, ranges []*noms.ReadRange, columns []string, primary, secondary durable.Index) (sql.RowIter, error) {
+	m := durable.NomsMapFromIndex(secondary)
 	nrr := noms.NewNomsRangeReader(idx.IndexSchema(), m, ranges)
 
 	covers := indexCoversCols(idx, columns)
 	if covers || idx.ID() == "PRIMARY" {
 		return NewCoveringIndexRowIterAdapter(ctx, idx, nrr, columns), nil
 	} else {
-		return NewIndexLookupRowIterAdapter(ctx, idx, nrr)
+		return NewIndexLookupRowIterAdapter(ctx, idx, primary, nrr)
 	}
 }
 
@@ -114,15 +120,20 @@ func DoltIndexFromLookup(lookup sql.IndexLookup) DoltIndex {
 	return lookup.(*doltIndexLookup).idx
 }
 
-func NewRangePartitionIter(lookup sql.IndexLookup) sql.PartitionIter {
+func NewRangePartitionIter(ctx *sql.Context, t *doltdb.Table, lookup sql.IndexLookup) (sql.PartitionIter, error) {
 	dlu := lookup.(*doltIndexLookup)
+	primary, secondary, err := dlu.idx.GetDurableIndexes(ctx, t)
+	if err != nil {
+		return nil, err
+	}
 	return &rangePartitionIter{
 		nomsRanges:   dlu.nomsRanges,
 		prollyRanges: dlu.prollyRanges,
 		curr:         0,
 		mu:           &sync.Mutex{},
-		rowData:      dlu.IndexRowData(),
-	}
+		secondary:    secondary,
+		primary:      primary,
+	}, nil
 }
 
 type rangePartitionIter struct {
@@ -130,7 +141,10 @@ type rangePartitionIter struct {
 	prollyRanges []prolly.Range
 	curr         int
 	mu           *sync.Mutex
-	rowData      durable.Index
+	// the rows of the table the index references
+	primary durable.Index
+	// the rows of the index itself
+	secondary durable.Index
 }
 
 // Close is required by the sql.PartitionIter interface. Does nothing.
@@ -143,7 +157,7 @@ func (itr *rangePartitionIter) Next(_ *sql.Context) (sql.Partition, error) {
 	itr.mu.Lock()
 	defer itr.mu.Unlock()
 
-	if types.IsFormat_DOLT_1(itr.rowData.Format()) {
+	if types.IsFormat_DOLT_1(itr.secondary.Format()) {
 		return itr.nextProllyPartition()
 	}
 	return itr.nextNomsPartition()
@@ -162,7 +176,8 @@ func (itr *rangePartitionIter) nextProllyPartition() (sql.Partition, error) {
 	return rangePartition{
 		prollyRange: pr,
 		key:         bytes[:],
-		rows:        itr.rowData,
+		primary:     itr.primary,
+		secondary:   itr.secondary,
 	}, nil
 }
 
@@ -179,7 +194,8 @@ func (itr *rangePartitionIter) nextNomsPartition() (sql.Partition, error) {
 	return rangePartition{
 		nomsRange: nr,
 		key:       bytes[:],
-		rows:      itr.rowData,
+		primary:   itr.primary,
+		secondary: itr.secondary,
 	}, nil
 }
 
@@ -187,7 +203,10 @@ type rangePartition struct {
 	nomsRange   *noms.ReadRange
 	prollyRange prolly.Range
 	key         []byte
-	rows        durable.Index
+	// the rows of the table the index refers to
+	primary durable.Index
+	// the index entries
+	secondary durable.Index
 }
 
 func (rp rangePartition) Key() []byte {
@@ -237,10 +256,6 @@ func (il *doltIndexLookup) String() string {
 	return fmt.Sprintf("doltIndexLookup:%s", il.idx.ID())
 }
 
-func (il *doltIndexLookup) IndexRowData() durable.Index {
-	return il.idx.IndexRowData()
-}
-
 // Index implements the interface sql.IndexLookup
 func (il *doltIndexLookup) Index() sql.Index {
 	return il.idx
