@@ -141,7 +141,12 @@ func DoltProceduresGetAll(ctx *sql.Context, db Database) ([]sql.StoredProcedureD
 		return nil, err
 	}
 
-	iter, err := index.RowIterForIndexLookup(ctx, lookup, tbl.sqlSch, nil)
+	dt, err := tbl.doltTable(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	iter, err := index.RowIterForIndexLookup(ctx, dt, lookup, tbl.sqlSch, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -265,7 +270,12 @@ func DoltProceduresGetDetails(ctx *sql.Context, tbl *WritableDoltTable, name str
 		return sql.StoredProcedureDetails{}, false, err
 	}
 
-	rowIter, err := index.RowIterForIndexLookup(ctx, indexLookup, tbl.sqlSch, nil)
+	dt, err := tbl.doltTable(ctx)
+	if err != nil {
+		return sql.StoredProcedureDetails{}, false, err
+	}
+
+	rowIter, err := index.RowIterForIndexLookup(ctx, dt, indexLookup, tbl.sqlSch, nil)
 	if err != nil {
 		return sql.StoredProcedureDetails{}, false, err
 	}
