@@ -75,6 +75,10 @@ func newRowIterator(ctx context.Context, tbl *doltdb.Table, projCols []string, p
 		return nil, err
 	}
 
+	if types.IsFormat_DOLT_1(tbl.Format()) {
+		return ProllyRowIterFromPartition(ctx, tbl, projCols, partition)
+	}
+
 	if schema.IsKeyless(sch) {
 		// would be more optimal to project columns into keyless tables also
 		return newKeylessRowIterator(ctx, tbl, projCols, partition)
@@ -115,10 +119,6 @@ func newKeylessRowIterator(ctx context.Context, tbl *doltdb.Table, projectedCols
 }
 
 func newKeyedRowIter(ctx context.Context, tbl *doltdb.Table, projectedCols []string, partition doltTablePartition) (sql.RowIter, error) {
-	if types.IsFormat_DOLT_1(tbl.Format()) {
-		return ProllyRowIterFromPartition(ctx, tbl, projectedCols, partition)
-	}
-
 	mapIter, err := iterForPartition(ctx, partition)
 	if err != nil {
 		return nil, err
@@ -186,7 +186,7 @@ func ProllyRowIterFromPartition(ctx context.Context, tbl *doltdb.Table, projecti
 	return index.NewProllyRowIter(ctx, sch, rows, iter, projections)
 }
 
-// Returns a |sql.RowIter| for a full table scan for the given |table|. If
+// TableToRowIter returns a |sql.RowIter| for a full table scan for the given |table|. If
 // |columns| is not empty, only columns with names appearing in |columns| will
 // have non-|nil| values in the resulting |sql.Row|s. If |columns| is empty,
 // values for all columns in the table are populated in each returned Row. The
