@@ -41,4 +41,13 @@ const Format718String = "7.18"
 const FormatLD1String = "__LD_1__"
 const FormatDolt1String = "__DOLT_1__"
 
+// A temporary format used for developing flatbuffers serialization of
+// top-of-DAG entities like StoreRoot, {Tag,WorkingSet,Commit}Head, etc.
+// Semantics are: __LD_1__ for everything that hasn't been migrated, and what
+// will become top-of-DAG in __DOLT_1__ for everything else.
+//
+// Things that will migrate are all structs leading up to table data and index
+// data maps.
+const FormatDoltDevString = "__DOLT_DEV__"
+
 var FormatDefaultString = FormatLD1String
