@@ -148,6 +148,10 @@ func NewHashSet(hashes ...Hash) HashSet {
 	return out
 }
 
+func (hs HashSet) Size() int {
+	return len(hs)
+}
+
 // Insert adds a Hash to the set.
 func (hs HashSet) Insert(hash Hash) {
 	hs[hash] = struct{}{}
@@ -181,3 +185,9 @@ func (hs HashSet) InsertAll(other HashSet) {
 		hs[h] = struct{}{}
 	}
 }
+
+func (hs HashSet) Empty() {
+	for h := range hs {
+		delete(hs, h)
+	}
+}
