@@ -27,10 +27,10 @@ import (
 )
 
 var goldenHash = hash.Hash{
-	0x1e, 0x5a, 0x87, 0xe7, 0xdb,
-	0xc8, 0x92, 0x89, 0xc1, 0x29,
-	0xbe, 0xa2, 0x9, 0xac, 0xcd,
-	0xad, 0x88, 0x9c, 0xef, 0xaf,
+	0xcb, 0x1d, 0xe1, 0xbd, 0x4a,
+	0x3c, 0x27, 0x18, 0xe, 0xba,
+	0xb7, 0xe8, 0x30, 0x44, 0x69,
+	0x3d, 0x86, 0x27, 0x26, 0x2d,
 }
 
 // todo(andy): need and analogous test in pkg prolly
