@@ -178,10 +178,10 @@ func (r *valueDecoder) readSequence(nbf *NomsBinFormat, kind NomsKind, leafSkipp
 	end := r.pos()
 
 	if level > 0 {
-		return newMetaSequence(r.vrw, r.byteSlice(start, end), offsets, length), nil
+		return newMetaSequence(nbf, r.vrw, r.byteSlice(start, end), offsets, length), nil
 	}
 
-	return newLeafSequence(r.vrw, r.byteSlice(start, end), offsets, length), nil
+	return newLeafSequence(nbf, r.vrw, r.byteSlice(start, end), offsets, length), nil
 }
 
 func (r *valueDecoder) readBlobSequence(nbf *NomsBinFormat) (sequence, error) {
